@@ -44,3 +44,20 @@ class ErrorAnalysisManagerKeys(object):
     NUM_LEAVES = 'num_leaves'
     FILTER_FEATURES = 'filter_features'
     REPORTS = 'reports'
+
+
+class SKLearn(object):
+    """Provide scikit-learn related constants."""
+
+    EXAMPLES = 'examples'
+    LABELS = 'labels'
+    PREDICTIONS = 'predictions'
+    PREDICT_PROBA = 'predict_proba'
+
+
+class ExplanationKeys(object):
+
+    EBM_GLOBAL_EXPLANATION_KEY = 'ebm_global'
+    EXPLANATION_TYPE_KEY = 'explanation_type'
+    GLOBAL_EXPLANATION_KEY = 'global_feature_importance'
+    LOCAL_EXPLANATION_KEY = 'local_feature_importance'
