@@ -13,6 +13,7 @@ from responsibleai.exceptions import DuplicateManagerConfigException
 from erroranalysis._internal.error_analyzer import ModelAnalyzer
 from erroranalysis._internal.error_report import (
     json_converter as report_json_converter, as_error_report)
+from responsibleai._interfaces import ErrorAnalysisData
 
 REPORTS = 'reports'
 CONFIG = 'config'
@@ -164,6 +165,11 @@ class ErrorAnalysisManager(BaseManager):
         self._categorical_features = None
         self._ea_config_list = []
         self._ea_report_list = []
+        self.analyzer = ModelAnalyzer(self._model,
+                                      self._train,
+                                      self._y_train,
+                                      self._feature_names,
+                                      self._categorical_features)
 
     def add(self, max_depth=3, num_leaves=31, filter_features=None):
         """Add an error analyzer to be computed later.
@@ -197,16 +203,11 @@ class ErrorAnalysisManager(BaseManager):
             if config.is_computed:
                 continue
             config.is_computed = True
-            analyzer = ModelAnalyzer(self._model,
-                                     self._train,
-                                     self._y_train,
-                                     self._feature_names,
-                                     self._categorical_features)
             max_depth = config.max_depth
             num_leaves = config.num_leaves
-            report = analyzer.create_error_report(config.filter_features,
-                                                  max_depth=max_depth,
-                                                  num_leaves=num_leaves)
+            report = self.analyzer.create_error_report(config.filter_features,
+                                                       max_depth=max_depth,
+                                                       num_leaves=num_leaves)
             self._ea_report_list.append(report)
 
     def get(self):
@@ -237,6 +238,21 @@ class ErrorAnalysisManager(BaseManager):
         props[Keys.REPORTS] = reports
         return props
 
+    def get_data(self):
+        """Get error analysis data
+
+        :return: A array of ErrorAnalysisConfig.
+        :rtype: List[ErrorAnalysisConfig]
+        """
+        return [
+            self._get_error_analysis(i) for i in self.list()["reports"]]
+
+    def _get_error_analysis(self, report):
+        error_analysis = ErrorAnalysisData()
+        error_analysis.maxDepth = report[Keys.MAX_DEPTH]
+        error_analysis.numLeaves = report[Keys.NUM_LEAVES]
+        return error_analysis
+
     @property
     def name(self):
         """Get the name of the error analysis manager.
