@@ -5,6 +5,7 @@
 
 import warnings
 import json
+import numpy as np
 from scipy.sparse import issparse
 from pathlib import Path
 from interpret_community.mimic.mimic_explainer import MimicExplainer
@@ -16,8 +17,12 @@ from interpret_community.common.constants import ModelTask
 from interpret_community.explanation.explanation import (
     save_explanation, load_explanation, FeatureImportanceExplanation)
 from responsibleai._internal.constants import (
-    ManagerNames, Metadata, ListProperties, ExplainerManagerKeys as Keys)
+    ManagerNames, Metadata, ListProperties, ExplanationKeys,
+    ExplainerManagerKeys as Keys)
 from responsibleai._managers.base_manager import BaseManager
+from responsibleai._interfaces import ModelExplanationData,\
+    PrecomputedExplanations, FeatureImportance, EBMGlobalExplanation
+from responsibleai._input_processing import _convert_to_list
 
 SPARSE_NUM_FEATURES_THRESHOLD = 1000
 IS_RUN = 'is_run'
@@ -155,6 +160,109 @@ class ExplainerManager(BaseManager):
             props[Keys.IS_COMPUTED] = False
         return props
 
+    def get_data(self):
+        """Get explanation data
+
+        :return: A array of ModelExplanationData.
+        :rtype: List[ModelExplanationData]
+        """
+        return [
+            self._get_interpret(i) for i in self.get()]
+
+    def _get_interpret(self, explanation):
+        interpretation = ModelExplanationData()
+
+        # List of explanations, key of explanation type is "explanation_type"
+        if explanation is not None:
+            mli_explanations = explanation.data(-1)["mli"]
+        else:
+            mli_explanations = None
+        local_explanation = self._find_first_explanation(
+            ExplanationKeys.LOCAL_EXPLANATION_KEY,
+            mli_explanations)
+        global_explanation = self._find_first_explanation(
+            ExplanationKeys.GLOBAL_EXPLANATION_KEY,
+            mli_explanations)
+        ebm_explanation = self._find_first_explanation(
+            ExplanationKeys.EBM_GLOBAL_EXPLANATION_KEY,
+            mli_explanations)
+
+        if explanation is not None and hasattr(explanation, 'method'):
+            interpretation.method = explanation.method
+
+        local_dim = None
+
+        if local_explanation is not None or global_explanation is not None\
+                or ebm_explanation is not None:
+            interpretation.precomputedExplanations = PrecomputedExplanations()
+
+        if local_explanation is not None:
+            try:
+                local_feature_importance = FeatureImportance()
+                local_feature_importance.scores = _convert_to_list(
+                    local_explanation["scores"])
+                if np.shape(local_feature_importance.scores)[-1] > 1000:
+                    raise ValueError("Exceeds maximum number of features for "
+                                     "visualization (1000). Please regenerate"
+                                     " the explanation using fewer features.")
+                local_feature_importance.intercept = _convert_to_list(
+                    local_explanation["intercept"])
+                # We can ignore perf explanation data.
+                # Note if it is added back at any point,
+                # the numpy values will need to be converted to python,
+                # otherwise serialization fails.
+                local_explanation["perf"] = None
+                interpretation.precomputedExplanations.localFeatureImportance\
+                    = local_feature_importance
+            except Exception as ex:
+                raise ValueError(
+                    "Unsupported local explanation type") from ex
+            if self._evaluation_examples is not None:
+
+                _feature_length = self._evaluation_examples.shape[1]
+                _row_length = self._evaluation_examples.shape[0]
+                local_dim = np.shape(local_feature_importance.scores)
+                if len(local_dim) != 2 and len(local_dim) != 3:
+                    raise ValueError(
+                        "Local explanation expected to be a 2D or 3D list")
+                if (len(local_dim) == 2 and
+                    (local_dim[1] != _feature_length or
+                     local_dim[0] != _row_length)):
+                    raise ValueError(
+                        "Shape mismatch: local explanation"
+                        "length differs from dataset")
+                if(len(local_dim) == 3 and
+                   (local_dim[2] != _feature_length or
+                        local_dim[1] != _row_length)):
+                    raise ValueError(
+                        "Shape mismatch: local explanation"
+                        " length differs from dataset")
+        if global_explanation is not None:
+            try:
+                global_feature_importance = FeatureImportance()
+                global_feature_importance.scores = _convert_to_list(
+                    global_explanation["scores"])
+                if 'intercept' in global_explanation:
+                    global_feature_importance.intercept\
+                        = _convert_to_list(
+                            global_explanation["intercept"])
+                interpretation.precomputedExplanations.globalFeatureImportance\
+                    = global_explanation
+            except Exception as ex:
+                raise ValueError("Unsupported global explanation type") from ex
+        if ebm_explanation is not None:
+            try:
+                ebm_feature_importance = EBMGlobalExplanation()
+                ebm_feature_importance.feature_list\
+                    = ebm_explanation["feature_list"]
+                interpretation.precomputedExplanations.ebmGlobalExplanation\
+                    = ebm_feature_importance
+
+            except Exception as ex:
+                raise ValueError(
+                    "Unsupported ebm explanation type") from ex
+        return interpretation
+
     @property
     def name(self):
         """Get the name of the explainer manager.
@@ -216,3 +324,15 @@ class ExplainerManager(BaseManager):
         if meta[IS_ADDED]:
             inst.add()
         return inst
+
+    def _find_first_explanation(self, key, mli_explanations):
+        if mli_explanations is None:
+            return None
+        new_array = [explanation for explanation
+                     in mli_explanations
+                     if explanation[
+                         ExplanationKeys.EXPLANATION_TYPE_KEY
+                     ] == key]
+        if len(new_array) > 0:
+            return new_array[0]["value"]
+        return None
